@@ -7,11 +7,11 @@ GeomQuantile <- proto(GeomPath, {
 	default_aes <- function(.) defaults(aes(weight=1, colour="grey50"), GeomPath$default_aes())
 
 	icon <- function(.) {
-		gTree(children=gList(
+		ggname(.$my_name(), gTree(children=gList(
 			linesGrob(c(0, 0.3, 0.5, 0.8, 1), c(0.8, 0.65, 0.6, 0.6, 0.8)),
 			linesGrob(c(0, 0.3, 0.5, 0.8, 1), c(0.55, 0.45, 0.5, 0.45, 0.55)),
 			linesGrob(c(0, 0.3, 0.5, 0.8, 1), c(0.3, 0.25, 0.4, 0.3, 0.2))
-		))
+		)))
 	}
 
 
