@@ -6,8 +6,19 @@ ScaleLinetype <- proto(ScaleDiscrete, expr={
 	max_levels <- function(.) 4
 	guide_legend_geom <- function(.) GeomPath
 	
+	# Documetation -----------------------------------------------
+
 	objname <- "linetype"
-	desc <- "Create a scale for categorical line types"
+	desc <- "Scale for line patterns"
+	
+	icon <- function(.) {
+		gTree(children=gList(
+			segmentsGrob(0, 0.25, 1, 0.25, gp=gpar(lty=1)),
+			segmentsGrob(0, 0.50, 1, 0.50, gp=gpar(lty=2)),
+			segmentsGrob(0, 0.75, 1, 0.75, gp=gpar(lty=3))
+		))
+	}
+	
 	examples <- function() {
 		# Fairly nonsensical example, but looking for better
 		# sample data set
